---
title: Global Options
description: "Vector's global options, allowing you configure global Vector-wide behavior."
---

In addition to [sources][docs.sources], [transforms][docs.transforms], and
[sinks][docs.sinks], Vector accepts global options that serve to configure
Vector as a whole and set defaults for component options.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/global-options.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" />

```toml
# OPTIONAL - General
  data_dir = "/var/lib/vector" # example, no default
  dns_servers = ["0.0.0.0:53"] # example, no default

  # OPTIONAL - Log schema
  [log_schema]
    host_key = "host" # default
    message_key = "message" # default
    timestamp_key = "timestamp" # default
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/var/lib/vector"]}
  groups={[]}
  name={"data_dir"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### data_dir

The directory used for persisting Vector state, such as on-disk buffers, file checkpoints, and more. Please make sure the Vector project has write permissions to this dir. See [Data Directory](#data-directory) for more info.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["0.0.0.0:53"]]}
  groups={[]}
  name={"dns_servers"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### dns_servers

The list of DNS servers Vector will use to resolve DNS requests. When set Vector will ignore the system configuration and use only the list of DNS servers provided. If this option is not set then Vector will attempt to use the system configuration.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"log_schema"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### log_schema

The default log schema that all Vector components operate on. See the [log data model page][docs.data-model.log] for more info.


<Fields filters={false}>


<Field
  common={false}
  defaultValue={"host"}
  enumValues={null}
  examples={["host","@host","instance","machine"]}
  groups={[]}
  name={"host_key"}
  path={"log_schema"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### host_key

The key used to hold the log host. See the [log data model page][docs.data-model.log#host] for more info.


</Field>


<Field
  common={false}
  defaultValue={"message"}
  enumValues={null}
  examples={["message","@message","msg"]}
  groups={[]}
  name={"message_key"}
  path={"log_schema"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### message_key

The key used to hold the log message. See the [log data model page][docs.data-model.log#message] for more info.


</Field>


<Field
  common={false}
  defaultValue={"timestamp"}
  enumValues={null}
  examples={["timestamp","@timestamp","datetime"]}
  groups={[]}
  name={"timestamp_key"}
  path={"log_schema"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### timestamp_key

The key used to represent when the log was generated. See the [log data model page][docs.data-model.log#timestamp] for more info.


</Field>


</Fields>

</Field>


</Fields>

## How It Works

### Data Directory

Vector requires a [`data_dir`](#data_dir) value for on-disk operations. Currently, the only
operation using this directory are Vector's on-disk buffers. Buffers, by
default, are memory-based, but if you switch them to disk-based you'll need to
specify a [`data_dir`](#data_dir).


[docs.data-model.log#host]: /docs/about/data-model/log/#host
[docs.data-model.log#message]: /docs/about/data-model/log/#message
[docs.data-model.log#timestamp]: /docs/about/data-model/log/#timestamp
[docs.data-model.log]: /docs/about/data-model/log/
[docs.sinks]: /docs/reference/sinks/
[docs.sources]: /docs/reference/sources/
[docs.transforms]: /docs/reference/transforms/
