---
delivery_guarantee: "at_least_once"
component_title: "Humio Logs"
description: "The Vector `humio_logs` sink batches `log` events to Humio via the HEC API."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+humio_logs%22
min_version: null
operating_systems: ["Linux","MacOS","Windows"]
service_name: "Humio Logs"
sidebar_label: "humio_logs|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/humio_logs.rs
status: "beta"
title: "Humio Logs Sink"
unsupported_operating_systems: []
---

The Vector `humio_logs` sink [batches](#buffers--batches) [`log`][docs.data-model.log] events to [Humio][urls.humio] via the [HEC API][urls.humio_hec].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/humio_logs.md.erb
-->

## Configuration

import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>

import TabItem from '@theme/TabItem';

<TabItem value="common">

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sinks.my_sink_id]
  # REQUIRED
  type = "humio_logs" # must be: "humio_logs"
  inputs = ["my-source-id"] # example
  token = "${TOKEN_ENV_VAR}" # example

  # OPTIONAL
  healthcheck = true # default
```

</TabItem>
<TabItem value="advanced">

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sinks.my_sink_id]
  # REQUIRED - General
  type = "humio_logs" # must be: "humio_logs"
  inputs = ["my-source-id"] # example
  token = "${TOKEN_ENV_VAR}" # example

  # OPTIONAL - General
  healthcheck = true # default
  host = "http://myhumiohost.com" # example, no default

  # OPTIONAL - Batch
  [sinks.my_sink_id.batch]
    max_size = 1049000 # default, bytes
    timeout_secs = 1 # default, seconds

  # OPTIONAL - Buffer
  [sinks.my_sink_id.buffer]
    # OPTIONAL
    type = "memory" # default, enum
    max_events = 500 # default, events, relevant when type = "memory"
    when_full = "block" # default, enum

    # REQUIRED
    max_size = 104900000 # example, bytes, relevant when type = "disk"

  # OPTIONAL - Request
  [sinks.my_sink_id.request]
    in_flight_limit = 10 # default, requests
    rate_limit_duration_secs = 1 # default, seconds
    rate_limit_num = 10 # default
    retry_attempts = -1 # default
    retry_initial_backoff_secs = 1 # default, seconds
    retry_max_duration_secs = 10 # default, seconds
    timeout_secs = 60 # default, seconds
```

</TabItem>
</Tabs>

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### batch

Configures the sink batching behavior.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={1049000}
  enumValues={null}
  examples={[1049000]}
  groups={[]}
  name={"max_size"}
  path={"batch"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  >

#### max_size

The maximum size of a batch, in bytes, before it is flushed. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### timeout_secs

The maximum age of a batch before it is flushed. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


</Fields>

</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"buffer"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### buffer

Configures the sink specific buffer behavior.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={500}
  enumValues={null}
  examples={[500]}
  groups={[]}
  name={"max_events"}
  path={"buffer"}
  relevantWhen={{"type":"memory"}}
  required={true}
  templateable={false}
  type={"int"}
  unit={"events"}
  >

#### max_events

The maximum number of [events][docs.data-model] allowed in the buffer.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[104900000]}
  groups={[]}
  name={"max_size"}
  path={"buffer"}
  relevantWhen={{"type":"disk"}}
  required={true}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  >

#### max_size

The maximum size of the buffer on the disk. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


<Field
  common={true}
  defaultValue={"memory"}
  enumValues={{"memory":"Stores the sink's buffer in memory. This is more performant, but less durable. Data will be lost if Vector is restarted forcefully.","disk":"Stores the sink's buffer on disk. This is less performant, but durable. Data will not be lost between restarts."}}
  examples={["memory","disk"]}
  groups={[]}
  name={"type"}
  path={"buffer"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### type

The buffer's type and storage mechanism.


</Field>


<Field
  common={false}
  defaultValue={"block"}
  enumValues={{"block":"Applies back pressure when the buffer is full. This prevents data loss, but will cause data to pile up on the edge.","drop_newest":"Drops new data as it's received. This data is lost. This should be used when performance is the highest priority."}}
  examples={["block","drop_newest"]}
  groups={[]}
  name={"when_full"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### when_full

The behavior when the buffer becomes full.


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  >

### healthcheck

Enables/disables the sink healthcheck upon start. See [Health Checks](#health-checks) for more info.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["http://myhumiohost.com"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### host

The optional host to send Humio logs to.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### request

Configures the sink request behavior.

<Fields filters={false}>


<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"requests"}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time. See [Rate Limits](#rate-limits) for more info.


</Field>


<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option. See [Rate Limits](#rate-limits) for more info.


</Field>


<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs) time window. See [Rate Limits](#rate-limits) for more info.


</Field>


<Field
  common={false}
  defaultValue={-1}
  enumValues={null}
  examples={[-1]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  >

#### retry_attempts

The maximum number of retries to make for failed requests. See [Retry Policy](#retry-policy) for more info.


</Field>


<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed request. Once, the first retry has failed the fibonacci sequence will be used to select future backoffs.


</Field>


<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.


</Field>


<Field
  common={false}
  defaultValue={60}
  enumValues={null}
  examples={[60]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly recommended that you do not lower value below the service's internal timeout, as this could create orphaned requests, pile on retries, and result in duplicate data downstream. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${TOKEN_ENV_VAR}","A94A8FE5CCB19BA61C4C08"]}
  groups={[]}
  name={"token"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### token

Your Humio ingestion token.


</Field>


</Fields>

## How It Works

### Buffers & Batches

import SVG from 'react-inlinesvg';

<SVG src="/img/buffers-and-batches-serial.svg" />

The `humio_logs` sink buffers & batches data as
shown in the diagram above. You'll notice that Vector treats these concepts
differently, instead of treating them as global concepts, Vector treats them
as sink specific concepts. This isolates sinks, ensuring services disruptions
are contained and [delivery guarantees][docs.guarantees] are honored.

*Batches* are flushed when 1 of 2 conditions are met:

1. The batch age meets or exceeds the configured [`timeout_secs`](#timeout_secs).
2. The batch size meets or exceeds the configured [`max_size`](#max_size).

*Buffers* are controlled via the [`buffer.*`](#buffer) options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Obtaining a Humio ingestion token

1. Register for a free account at [Humio.com](https://www.humio.com/getting-started)

2. Get your Ingest token following these  [docs](https://docs.humio.com/ingesting-data/ingest-tokens/).

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issie][urls.new_humio_logs_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model]: /docs/about/data-model/
[docs.guarantees]: /docs/about/guarantees/
[urls.humio]: https://humio.com
[urls.humio_hec]: https://docs.humio.com/integrations/data-shippers/hec/
[urls.new_humio_logs_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+humio_logs
