---
delivery_guarantee: "at_least_once"
component_title: "STDIN"
description: "The Vector `stdin` source ingests data through standard input (STDIN) and outputs `log` events."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+stdin%22
min_version: null
operating_systems: ["Linux","MacOS","Windows"]
service_name: "STDIN"
sidebar_label: "stdin|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/stdin.rs
status: "prod-ready"
title: "STDIN Source"
unsupported_operating_systems: []
---

The Vector `stdin` source ingests data through standard input (STDIN) and [outputs `log` events](#output).

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/stdin.md.erb
-->

## Configuration

import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>

import TabItem from '@theme/TabItem';

<TabItem value="common">

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED - General
  type = "stdin" # must be: "stdin"

  # OPTIONAL - Context
  host_key = "host" # default
```

</TabItem>
<TabItem value="advanced">

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED - General
  type = "stdin" # must be: "stdin"

  # OPTIONAL - Context
  host_key = "host" # default

  # OPTIONAL - General
  max_length = 102400 # default, bytes
```

</TabItem>
</Tabs>

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={"host"}
  enumValues={null}
  examples={["host"]}
  groups={[]}
  name={"host_key"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### host_key

The key name added to each event representing the current host. This can also be globally set via the [global [`host_key`](#host_key) option][docs.reference.global-options#host_key]. See [Context](#context) for more info.


</Field>


<Field
  common={false}
  defaultValue={102400}
  enumValues={null}
  examples={[102400]}
  groups={[]}
  name={"max_length"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  >

### max_length

The maxiumum bytes size of a message before it is discarded.


</Field>


</Fields>

## Output

The `stdin` source ingests data through standard input (STDIN) and [outputs `log` events](#output).
For example:


Given the following input:

```text
2019-02-13T19:48:34+00:00 [info] Started GET "/" for 127.0.0.1
```

A log event will be output with the following structure:

```json
{
  "timestamp": <current_timestamp>,
  "message": "2019-02-13T19:48:34+00:00 [info] Started GET "/" for 127.0.0.1",
  "host": "<local_hostname>"
}
```

More detail on the output schema is below.

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["my.host.com"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### host

The local hostname.



</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  groups={[]}
  name={"message"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### message

The raw message, unaltered.



</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  groups={[]}
  name={"timestamp"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"timestamp"}
  unit={null}
  >

### timestamp

The exact time the event was ingested.


</Field>


</Fields>

## How It Works

### Context

By default, the `stdin` source will add context
keys to your events via the [`host_key`](#host_key)
options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Line Delimiters

Each line is read until a new line delimiter (the `0xA` byte) is found.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.reference.global-options#host_key]: /docs/reference/global-options/#host_key
