---
component_title: "Add Fields"
description: "The Vector `add_fields` transform accepts and outputs `log` events allowing you to add one or more log fields."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+add_fields%22
min_version: null
service_name: "Add Fields"
sidebar_label: "add_fields|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/add_fields.rs
status: "prod-ready"
title: "Add Fields Transform"
---

The Vector `add_fields` transform accepts and [outputs `log` events](#output) allowing you to add one or more log fields.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/add_fields.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[transforms.my_transform_id]
  # REQUIRED - General
  type = "add_fields" # must be: "add_fields"
  inputs = ["my-source-id"] # example

  # REQUIRED - Fields
  [transforms.my_transform_id.fields]
    string_field = "string value" # example
    env_var_field = "${ENV_VAR}" # example
    int_field = 1 # example
    float_field = 1.2 # example
    bool_field = true # example
    timestamp_field = 1979-05-27T00:32:00Z # example
    parent = {child = "child_value"} # example
    list_field = ["first", "second", "third"] # example
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"fields"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  >

### fields

A table of key/value pairs representing the keys to be added to the event.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"string_field":"string value"},{"env_var_field":"${ENV_VAR}"},{"int_field":1},{"float_field":1.2},{"bool_field":true},{"timestamp_field":"1979-05-27 00:32:00 -0700"},{"parent":{"child":"child_value"}},{"list_field":["first","second","third"]}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"fields"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"*"}
  unit={null}
  >

#### `[field-name]`

The name of the field to add. Accepts all [supported types][docs.configuration#types]. Use `.` for adding nested fields.


</Field>


</Fields>

</Field>


</Fields>

## Output

The `add_fields` transform accepts and [outputs `log` events](#output) allowing you to add one or more log fields.
For example:


Given the following configuration:

<CodeHeader fileName="vector.toml" />

```toml
[transforms.my_transform]
  type = "add_fields"
  inputs = [...]

  [transforms.my_transform.fields]
    field1 = "string value"
    field2 = 1
    field3 = 2.0
    field4 = true
    field5 = 2019-05-27T07:32:00Z
    field6 = ["item 1", "item 2"]
    field7.nested = "nested value",
    field8 = "#{HOSTNAME}"
    field9 = "{{field1}} {{field2}}"
```

A [`log` event][docs.data-model.log] will be output with the following structure:

```javascript
{
  // ... existing fields
  "field1": "string value",
  "field2": 1,
  "field3": 2.0,
  "field4": true,
  "field5": <timestamp:2019-05-27T07:32:00Z>,
  "field6.0": "item1",
  "field6.1": "item2",
  "field7.nested": "nested value",
  "field8": "my.hostname.com"
}
```

While unrealistic, this example demonstrates the various accepted
[types][docs.configuration#types] and how they're repsented in Vector's
internal [log structure][docs.data-model.log].

## How It Works

### Arrays

The `add_fields` transform will support [TOML arrays][urls.toml_array]. Keep in
mind that the values must be simple type (not tables), and each value must the
same type. You cannot mix types:

```toml
[transforms.<transform-id>]
  # ...

  [transforms.<transform-id>.fields]
    my_array = ["first", "second", "third"]
```

Results in:

```json
{
  "my_array.0": "first",
  "my_array.1": "second",
  "my_array.2": "third"
}
```

Learn more about how [`log` events][docs.data-model.log] are structured.

### Complex Transforming

The `add_fields` transform is designed for simple key additions. If you need
more complex transforming then we recommend using a more versatile transform
like the [`lua` transform][docs.transforms.lua].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Key Conflicts

Keys specified in this transform will replace existing keys.

### Nested Fields

The `add_fields` transform will support dotted keys or [TOML
tables][urls.toml_table]. We recommend the dotted key syntax since it is less
verbose for this usecase:

```toml
[transforms.<transform-id>]
  # ...

  [transforms.<transform-id>.fields]
    parent.child.grandchild = "my_value"
```

Results in:

```json
{
  "parent.child.grandchild": "my_value"
}
```

Learn more about how [`log` events][docs.data-model.log] are structured.

### Removing Fields

See the [`remove_fields` transform][docs.transforms.remove_fields].

### Types

All supported [configuration value types][docs.configuration#types] are accepted.
This includes primitivate types (`string`, `int`, `float`, `boolean`) and
special types, such as [arrays](#arrays) and [nested fields](#nested-fields).



### Value Templating

It is possible to use template values in the field. If an input lacks one of the keys needed for a templated field it
will drop that field from the output.

```toml
[transforms.<transform-id>]
  # ...

  [transforms.<transform-id>.fields]
    my_field = "{{timestamp}} {{message}}"
```


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.configuration#types]: /docs/setup/configuration/#types
[docs.data-model.log]: /docs/about/data-model/log/
[docs.transforms.lua]: /docs/reference/transforms/lua/
[docs.transforms.remove_fields]: /docs/reference/transforms/remove_fields/
[urls.toml_array]: https://github.com/toml-lang/toml#array
[urls.toml_table]: https://github.com/toml-lang/toml#table
