---
component_title: "Merge"
description: "The Vector [`merge`](#merge) transform accepts and outputs `log` events allowing you to merge partial log events into a single event."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+merge%22
min_version: null
service_name: "Merge"
sidebar_label: "merge|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/merge.rs
status: "beta"
title: "Merge Transform"
---

The Vector [`merge`](#merge) transform accepts and [outputs `log` events](#output) allowing you to merge partial log events into a single event.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/merge.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[transforms.my_transform_id]
  # REQUIRED
  type = "merge" # must be: "merge"
  inputs = ["my-source-id"] # example

  # OPTIONAL
  merge_fields = ["message"] # default
  partial_event_marker_field = "_partial" # default
  stream_discriminant_fields = [] # default
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={["message"]}
  enumValues={null}
  examples={[["message"]]}
  groups={[]}
  name={"merge_fields"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### merge_fields

Fields to merge. The values of these fields will be merged into the first partial event. Fields not specified here will be ignored. Merging process takes the first partial event and the base, then it merges in the fields from each successive partial event, until a non-partial event arrives. Finally, the non-partial event fields are merged in, producing the resulting merged event.


</Field>


<Field
  common={true}
  defaultValue={"_partial"}
  enumValues={null}
  examples={["_partial"]}
  groups={[]}
  name={"partial_event_marker_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### partial_event_marker_field

The field that indicates that the event is partial. A consequent stream of partial events along with the first non-partial event will be merged together.


</Field>


<Field
  common={true}
  defaultValue={[]}
  enumValues={null}
  examples={[[]]}
  groups={[]}
  name={"stream_discriminant_fields"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### stream_discriminant_fields

An ordered list of fields to distinguish streams by. Each stream has a separate partial event merging state. Should be used to prevent events from unrelated sources from mixing together, as this affects partial event processing.


</Field>


</Fields>

## Output

The [`merge`](#merge) transform accepts and [outputs `log` events](#output) allowing you to merge partial log events into a single event.
For example:


import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="default"
  values={[{"label":"Default","value":"default"},{"label":"With Merge Fields","value":"with-merge-fields"}]}>

import TabItem from '@theme/TabItem';

<TabItem value="default">

Given the following _default_ configuration:

<CodeHeader fileName="vector.toml" />

```toml
[transforms.merge_events]
  type = "merge"
  inputs = [...]
```

And these three partial [`log` events][docs.data-model.log]:

<CodeHeader fileName="first log event" />

```javascript
{
  "message": "First",
  "_partial": true,
  "custom_string_field": "value1",
  "custom_int_field": 1
}
```

and

<CodeHeader fileName="second log event" />

```javascript
{
  "message": "Second",
  "_partial": true,
  "custom_string_field": "value2",
  "custom_int_field": 2
}
```

and

<CodeHeader fileName="third log event" />

```javascript
{
  "message": "Third",
  "custom_string_field": "value3",
  "custom_int_field": 3
}
```

A single _merged_ log event will be produced:

```javascript
{
  "message": "FirstSecondThird",
  "custom_string_field": "value1",
  "custom_int_field": 1
}
```

Notice that `custom_string_field` and `custom_int_field` were not overridden. This is because they were not listed in the [`merge_fields`](#merge_fields) option.

</TabItem>

<TabItem value="with-merge-fields">

Given the following configuration:

<CodeHeader fileName="vector.toml" />

```toml
[transforms.merge_events]
  type = "merge"
  inputs = [...]
  merge_fields = ["message", "custom_string_field", "custom_int_field"]
```

And these three partial [`log` events][docs.data-model.log]:

<CodeHeader fileName="first log event" />

```javascript
{
  "message": "First",
  "_partial": true,
  "custom_string_field": "value1",
  "custom_int_field": 1
}
```

and

<CodeHeader fileName="second log event" />

```javascript
{
  "message": "Second",
  "_partial": true,
  "custom_string_field": "value2",
  "custom_int_field": 2
}
```

and

<CodeHeader fileName="third log event" />

```javascript
{
  "message": "Third",
  "custom_string_field": "value3",
  "custom_int_field": 3
}
```

A single _merged_ log event will be produced:

```javascript
{
  "message": "FirstSecondThird",
  "custom_string_field": "value1value2value3",
  "custom_int_field": 3
}
```

Notice that `custom_string_field` is concatenated and `custom_int_field` overridden. This is because it was specified in the [`merge_fields`](#merge_fields) option.

</TabItem>
</Tabs>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### When to use this transform

Where possible, Vector will handle event merging at the source level. For
example, the [`file`][docs.sources.file] contains a `message_start_indicator`
option and the [`docker`][docs.sources.file] contains an `auto_partial_merge`
option. Both of these options should be used instead of this transform.
Unfortunately, merging logs is not always this straight forward. It is
precisely these edge cases that this transform hopes to solve.

If you're using this transform for a common use case, please consider
[opening an issue][urls.new_feature_request] to let us know.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.sources.file]: /docs/reference/sources/file/
[urls.new_feature_request]: https://github.com/timberio/vector/issues/new?labels=type%3A+new+feature
